summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmconeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmconeedit.h')
-rw-r--r--kpovmodeler/pmconeedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmconeedit.h b/kpovmodeler/pmconeedit.h
index d5210124..88c2601a 100644
--- a/kpovmodeler/pmconeedit.h
+++ b/kpovmodeler/pmconeedit.h
@@ -39,9 +39,9 @@ class PMConeEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMConeEdit with tqparent and name
*/
- PMConeEdit( TQWidget* tqparent, const char* name = 0 );
+ PMConeEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMConeEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMConeEdit with tqparent and name
+ * Creates a PMConeEdit with parent and name
*/